@@ -424,10 +424,10 @@ namespace FFPACK {
         const RNS& _domain;
 
     public:
-        rnsRandIter(const RNS& R, size_t size=0, uint64_t seed=0)
+        rnsRandIter(const RNS& R, uint64_t seed=0)
         : _domain(R) {
             for(const auto& F : R._field_rns)
-                _RNS_rand.emplace_back(F,size,seed);
+                _RNS_rand.emplace_back(F,seed);
         }
 
         /** RNS ring Element random assignement.
